@@ -33,10 +33,9 @@ around new => sub ( $orig, $self, %args ) {
         syntax      => 'Kolon',                                                             # Kolon, TTerse
         module      => [ 'Text::Xslate::Bridge::TT2Like', 'Text::Xslate::Bridge::Star' ],
         function    => {
-
-            # i18n => sub {
-            #     return i18n( \@_ );
-            # },
+            l10n => sub {
+                return l10n( \@_ );
+            },
         },
     };
 
